/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core;

import net.sourceforge.wurfl.core.resource.ModelDevice;
import net.sourceforge.wurfl.core.resource.ModelDeviceWithAncestorId;
import net.sourceforge.wurfl.core.resource.WURFLModel;
import net.sourceforge.wurfl.core.utils.StringUtils;

/**
 * Abstract implementation of DeviceProvider.
 *
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: AbstractDeviceProvider.java 668 2011-06-14 07:07:44Z ermanno.franco $
 */
public abstract class AbstractDeviceProvider implements DeviceProvider {

    /**
     * The model used as backend
     */
    protected final WURFLModel model;

    /**
     * Build DeviceProvider by WURFLModel.
     *
     * @param model The wurflModel used as backend.
     */
    public AbstractDeviceProvider(WURFLModel model) {
        this.model = model;
    }

    /**
     * This method get a ModelDevice from WURFLModel.
     *
     * @param deviceId Th requested device identifier.
     * @return a ModelDevice identified by deviceId.
     */
    protected final ModelDeviceWithAncestorId getModelDeviceWithAncestorId(String deviceId)
            throws DeviceNotDefinedException {

        ModelDevice modelDevice = model.getDeviceById(deviceId);
        String ancestorId = model.getDeviceAncestor(modelDevice).getID();

        return new ModelDeviceWithAncestorId(modelDevice,ancestorId);
    }

}
