/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core;

import net.sourceforge.wurfl.core.resource.ModelDevice;
import net.sourceforge.wurfl.core.resource.WURFLModel;
import org.apache.commons.lang.Validate;

/**
 * {@link CapabilitiesHolderFactory} default implementation
 * <p>
 * Build instances of {@link DefaultCapabilitiesHolder}.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: DefaultCapabilitiesHolderFactory.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class DefaultCapabilitiesHolderFactory extends
		AbstractCapabilitiesHolderFactory {

	/**
	 * Build DefaultCapabilitiesHolderFactory by WURFL model.
	 * 
	 * @param model
	 *            The WURFLModel used by this DefaultCapabilitiesHolderFactory.
	 */
	public DefaultCapabilitiesHolderFactory(WURFLModel model) {
		super(model);
	}

	/**
	 * {@inheritDoc}
	 */
	public CapabilitiesHolder create(ModelDevice modelDevice) {

		Validate.notNull(modelDevice, "modelDevice is null");

		return new DefaultCapabilitiesHolder(new DefaultCapabilitiesLoader(
				modelDevice, model));
	}

}
