/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.cache;

import net.sf.ehcache.Cache;
import net.sf.ehcache.Element;

/**
 * {@link CacheProvider}'s EhCache implementation.
 * 
 * <p>
 * Add EhCache support to WURFL api. for more info visit the <a
 * href="http://ehcache.sourceforge.net">EHCache site</a>
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: EhCacheProvider.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class EhCacheProvider implements CacheProvider {

	/** EhCache instance */
	private Cache cache;

	/** Default Constructor */
	public EhCacheProvider() {
		// Empty
	}

	/**
	 * Constructor by EhCache cache
	 * 
	 * @param cache
	 *            Cache instance.
	 */
	public EhCacheProvider(Cache cache) {
		this.cache = cache;
	}

	/**
	 * Returns the held cache.
	 * 
	 * @return Held {@link Cache} instance.
	 */
	public Cache getCache() {
		return cache;
	}

	/**
	 * Set the underlying cache instance.
	 * 
	 * @param cache The EhCache {@link Cache} instance.
	 */
	public void setCache(Cache cache) {
		this.cache = cache;
	}

	/**
	 * {@inheritDoc}
	 */
	public void clear() {
		cache.removeAll();
	}

	/**
	 * {@inheritDoc}
	 */
	public Object get(Object key) {
		
		Element item = cache.get(key);

		Object stored = null;
		if (item != null) {
			// Can be expired
			stored = item.getObjectValue();
		}

		return stored;
	}

	/**
	 * {@inheritDoc}
	 */
	public void put(Object key, Object value) {
		Element item = new Element(key, value);
		cache.put(item);
	}

}
