/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.classifiers;

import net.sourceforge.wurfl.core.matchers.Matcher;
import org.apache.commons.lang.text.StrBuilder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * {@link Filter} base implementation.
 * <p/>
 * <p>
 * The {@link net.sourceforge.wurfl.core.matchers.Matcher} decides if this object can handle the given user-agent.
 * Stores the classified device in held {@link FilteredDevices} instance.
 * </p>
 *
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: BaseFilter.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class BaseFilter implements Filter {

    /**
     * The held Handler
     */
    private final Matcher matcher;

    /**
     * Classified device identifiers
     */
    private FilteredDevices filteredDevices;

    /**
     * Log
     */
    private final Logger logger = LoggerFactory.getLogger(BaseFilter.class);

    /**
     * Constructor by {@link Matcher} and {@link FilteredDevices}.
     *
     * @param matcher The matcher used by this object.
     */
    public BaseFilter(Matcher matcher) {
        this.matcher = matcher;
        this.filteredDevices = new FilteredDevices();
    }

    /**
     * Use the Handler to know if is possible to handle the user-agent.
     */
    public boolean canHandle(String userAgent) {
        return matcher.canHandle(userAgent);
    }

    /**
     * Add the given device id and user-agent to collected devices.
     */
    public void filter(String userAgent, String deviceID) {

        if (logger.isTraceEnabled()) {
            StrBuilder logBuilder = new StrBuilder();
            logBuilder.append("Putting Device: ").append(deviceID).append(
                    " into filter");
            logger.trace(logBuilder.toString());
        }

        this.filteredDevices = filteredDevices.putDevice(matcher.normalize(userAgent), deviceID);
    }

    /**
     * Return the held {@link FilteredDevices}.
     */
    public FilteredDevices getFilteredDevices() {
        return filteredDevices;
    }

}
