/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.classifiers;


/**
 * Filter interface.
 * <p>
 * This is responsible to classify devices based to user-agent.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: Filter.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public interface Filter {

	/**
	 * It returns if this class can classify the given user-agent.
	 * 
	 * @param userAgent
	 *            The user-agent to probr.
	 * @return True if this classifier can handle <code>userAgent</code>.
	 */
	boolean canHandle(String userAgent);

	/**
	 * Classify the given deviceId with corresponding user-agent.
	 * 
	 * @param userAgent
	 *            The user-agent to classify.
	 * @param deviceID
	 *            The device identifier corresponding to given user-agent.
	 */
	void filter(String userAgent, String deviceID);
	
	/**
	 * Returns collected {@link FilteredDevices}.
	 */
	FilteredDevices getFilteredDevices();

}
