/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.classifiers;

import net.sourceforge.wurfl.core.matchers.Matcher;
import net.sourceforge.wurfl.core.matchers.MatcherChain;

import java.util.Iterator;

/**
 * Factory used to build {@link FilterChain}.
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: FilterChainFactory.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class FilterChainFactory {

	/** Held FilterChain */
	private FilterChain chain = new FilterChain();


	public FilterChainFactory(MatcherChain matcherChain) {
		init(matcherChain);
	}

	/**
	 * Build the filters by matchers list.
	 */
	private void init(MatcherChain matcherChain) {
		for (Iterator iterator = matcherChain.getMatchers().iterator(); iterator
				.hasNext();) {
			Matcher m = (Matcher) iterator.next();
			chain.add(new BaseFilter(m));
		}
	}

	/**
	 * Return held FilterChain instance.
	 * 
	 * @return FilterChain build by this factory.
	 */
	public FilterChain create() {
		return chain;
	}

}
