/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.SortedSet;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: AndroidMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class AndroidMatcher extends AbstractMatcher {


    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public AndroidMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    public boolean canHandle(String userAgent) {
        return userAgent.startsWith("Mozilla") && org.apache.commons.lang.StringUtils.contains(userAgent, "Android");
    }

    protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
                                              String userAgent) {
        int tolerance = StringUtils.indexOfOrLength(userAgent, " ", StringUtils.indexOfOrLength(userAgent, "Android"));
        return StringUtils.risMatch(userAgentsSet, userAgent, tolerance);
    }


    private static final Map ANDROIDS = new LinkedHashMap();

    static {
        ANDROIDS.put("", "generic_android");
        ANDROIDS.put("1_5", "generic_android_ver1_5");
        ANDROIDS.put("1_6", "generic_android_ver1_6");
        ANDROIDS.put("2_0", "generic_android_ver2");
        ANDROIDS.put("2_1", "generic_android_ver2_1");
        ANDROIDS.put("2_2", "generic_android_ver2_2");
        ANDROIDS.put("2_3", "generic_android_ver2_3");
        ANDROIDS.put("3_0", "generic_android_ver3_0");
    }

    private static final String GENERIC_ANDROID = "generic_android";

    protected String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {
        String userAgent = request.getUserAgent();
        if (isFroyo(userAgent)) {
            return "generic_android_ver2_2";
        }
        final String version = androidOsVersion(userAgent);
        String deviceId = (String) ANDROIDS.get(version);
        if (deviceId != null) {
            return deviceId;
        }

        return GENERIC_ANDROID;
    }

    private boolean isFroyo(String userAgent) {
        return org.apache.commons.lang.StringUtils.contains(userAgent, "Froyo");
    }

    private static final Pattern ANDROID_OS_VERSION_PATTERN = Pattern.compile("Android[\\s/](\\d).(\\d)");

    private String androidOsVersion(String userAgent) {
        Matcher matcher = ANDROID_OS_VERSION_PATTERN.matcher(userAgent);
        return matcher.find() ? (matcher.group(1) + "_" + matcher.group(2)) : "";
    }
}
