/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import org.apache.commons.lang.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: AppleMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class AppleMatcher extends AbstractMatcher {


    private static final String[] APPLE_KEYOWRDS = new String[]{"iPhone", "iPod", "iPad"};

    /**
     *
     *
     * @param normalizer
     */
    public AppleMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
     * Checks given UA contains "iPhone" or "iPod" or iPad
     */
    public boolean canHandle(final String userAgent) {
        return net.sourceforge.wurfl.core.utils.StringUtils.containsAnyOf(userAgent, APPLE_KEYOWRDS);
    }

    /**
     * Apply RIS(First Semicolon).
     */
    protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
                                              String userAgent) {

        int tolerance;
        if (userAgent.startsWith("Apple")) {
            tolerance = thirdSpaceOrLength(userAgent);
        } else {
            tolerance = net.sourceforge.wurfl.core.utils.StringUtils.firstSemiColon(userAgent);
        }

        if (logger.isDebugEnabled()) {
            logger.debug("Applying RIS(First Semicolon/Third Space ) UA: " + userAgent);
        }

        return net.sourceforge.wurfl.core.utils.StringUtils.risMatch(userAgentsSet, userAgent, tolerance);

    }

    private static int thirdSpaceOrLength(String userAgent) {
        return net.sourceforge.wurfl.core.utils.StringUtils.ordinalIndexOfOrLength(userAgent, " ", 3);
    }

    private static final String IPOD = "iPod";
    private static final String IPAD = "iPad";

    protected String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {

        final String userAgent = request.getUserAgent();
        if (StringUtils.contains(userAgent, IPAD)) {
            return "apple_ipad_ver1";
        }

        if (StringUtils.contains(userAgent, IPOD)) {
            return "apple_ipod_touch_ver1";
        }

        return "apple_iphone_ver1";

    }
}
