/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;
import net.sourceforge.wurfl.core.utils.UserAgentUtils;
import org.apache.commons.collections.CollectionUtils;

import java.util.HashSet;
import java.util.Set;
import java.util.SortedSet;

/**
 * This is a matcher for BOTs
 *
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $id$
 */
public class BotMatcher extends AbstractMatcher {

    private static final int BOT_TOLERANCE = 4;
    private static final String GENERIC_WEB_CRAWLER = "generic_web_crawler";

    private final Set bots = new HashSet();
    private static final String BOT_KEYWORDS = "/net/sourceforge/wurfl/core/handlers/botskeywords.properties";

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public BotMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
        bots.addAll(UserAgentUtils.keys(BOT_KEYWORDS));
    }


    public boolean canHandle(String userAgent) {
        return CollectionUtils.find(bots, UserAgentUtils.isContainedIn(userAgent)) != null;
    }

    protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {
        return StringUtils.ldMatch(userAgentsSet, userAgent, BOT_TOLERANCE);
    }

    protected String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {
        return GENERIC_WEB_CRAWLER;
    }
}
