/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.Iterator;
import java.util.SortedSet;
import java.util.TreeSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: CatchAllMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class CatchAllMatcher extends AbstractMatcher {

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public CatchAllMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
     * Returns always true.
     */
    public boolean canHandle(String userAgent) {
        return true;
    }

	protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {
		if (userAgent.startsWith("Mozilla")) {
			if (userAgent.startsWith("Mozilla/4")) {
				return StringUtils
						.ldMatch(getMozillaData(userAgentsSet, "Mozilla/4"), userAgent, MOZILLA_LD_TOLLERANCE);
			}

			if (userAgent.startsWith("Mozilla/5")) {
				return StringUtils
						.ldMatch(getMozillaData(userAgentsSet, "Mozilla/5"), userAgent, MOZILLA_LD_TOLLERANCE);
			}

			return StringUtils.ldMatch(getMozillaData(userAgentsSet, "Mozilla"), userAgent, MOZILLA_LD_TOLLERANCE);
		}
		
		return super.lookForMatchingUserAgent(userAgentsSet, userAgent);
	}

	private SortedSet getMozillaData(SortedSet userAgentsSet, String starting) {

		SortedSet set = new TreeSet();
		for (Iterator iterator = userAgentsSet.iterator(); iterator.hasNext();) {
			String userAgent = (String) iterator.next();
			if (userAgent != null && userAgent.startsWith(starting)) {
				set.add(userAgent);
			}
		}
		return set;
	}

	private static final int MOZILLA_LD_TOLLERANCE = 4;
}
