/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: DoCoMoMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class DoCoMoMatcher extends AbstractMatcher {

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public DoCoMoMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
	 * Checks given UA starts with "DoCoMo"
	 */
	public boolean canHandle(String userAgent) {
		return userAgent.startsWith("DoCoMo");
	}

    /**
     * Does not perform anything. It returns always null. DoCoMo are direct match
     * only.
     */
    protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
                                              String userAgent) {

        // docomo is direct match only
        return null;
    }

    protected String applyRecoveryMatch(WURFLRequest request,
                                        FilteredDevices filteredDevices) {
        if (request.getUserAgent().startsWith("DoCoMo/2")) {
            return "docomo_generic_jap_ver2";
        }
        return "docomo_generic_jap_ver1";
    }

}
