/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: KDDIMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class KDDIMatcher extends AbstractMatcher {

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public KDDIMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
	 * Checks UA containing "KDDI"
	 */
	public boolean canHandle(String userAgent) {
		return userAgent.indexOf("KDDI") != -1;
	}

    /**
     * 
     */
    protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
                                              String userAgent) {

        int tolerance = tolerance(userAgent);
        if (logger.isDebugEnabled()) {
            logger.debug("Applying RIS with tolerance[" + tolerance + "] UA: " + userAgent);
        }

        return StringUtils.risMatch(userAgentsSet, userAgent, tolerance);
    }

    private int tolerance(String userAgent) {
        if (userAgent.startsWith("KDDI/")) {
            return StringUtils.secondSlash(userAgent);
        }
        if (userAgent.startsWith("KDDI")) {
            return StringUtils.firstSlash(userAgent);
        }

        return StringUtils.indexOfOrLength(userAgent, ")");
    }

    protected String applyRecoveryMatch(WURFLRequest request,
                                        FilteredDevices filteredDevices) {
        if (request.getUserAgent().indexOf("Opera") != -1) {
            return "opera";
        }
        return "opwv_v62_generic";
    }
}
