/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: LGMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class LGMatcher extends AbstractMatcher {


    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public LGMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
	 * Checks given UA starts with "LG"
	 */
	public boolean canHandle(String userAgent) {
		return userAgent.startsWith("lg") || org.apache.commons.lang.StringUtils.contains(userAgent, "LG-") || org.apache.commons.lang.StringUtils.contains(userAgent, "LGE");
	}

    protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {
        int tolerance = StringUtils.indexOfOrLength(userAgent, "/", userAgent.indexOf("LG"));
        if (logger.isDebugEnabled()) {
            logger.debug("Applying RIS with tolerance [" + tolerance + "] UA: " + userAgent);
        }
        return StringUtils.risMatch(userAgentsSet, userAgent, tolerance);

    }

}
