/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 * @author Fantayeneh Asres Gizaw
 */
public class LGUPLUSMatcher extends AbstractMatcher {


    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public LGUPLUSMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    public boolean canHandle(String userAgent) {
		return StringUtils.containsAnyOf(userAgent, new String[]{"lgtelecom", "LGUPLUS"});
	}

    protected String applyConclusiveMatch(WURFLRequest request, FilteredDevices filteredDevices) {
        return Constants.GENERIC;
    }


    private static final Map LGPLUSES = new LinkedHashMap();

    static {
        LGPLUSES.put("generic_lguplus_rexos_facebook_browser", new String[]{"Windows NT 5", "POLARIS"});
        LGPLUSES.put("generic_lguplus_rexos_webviewer_browser", new String[]{"Windows NT 5"});
        LGPLUSES.put("generic_lguplus_winmo_facebook_browser", new String[]{"Windows CE", "POLARIS"});
        LGPLUSES.put("generic_lguplus_android_webkit_browser", new String[]{"Android", "AppleWebKit"});

    }

    protected String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {
        for(Iterator itx = LGPLUSES.entrySet().iterator(); itx.hasNext();) {
            Map.Entry entry = (Map.Entry) itx.next(); 
            if(StringUtils.containsAllOf(request.getUserAgent(), (String[]) entry.getValue())) {
                return (String) entry.getKey();
            }
        }
        return "generic_lguplus";
    }
}
