/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;

/**
 * A user-agent matcher.
 * 
 * <p>
 * The user-agent matchers classes must implement this interface.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: Matcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public interface Matcher {

	/**
	 * Return if this matcher can handle given request.
	 * 
	 * @param userAgent
     *
	 */
	boolean canHandle(String userAgent);

	/**
	 * Perform matching. It never returns null, at least it returns
	 * <code>generic</code> device.
	 * 
	 * @param request
	 *            The request to match.
	 * @return Return the matched device identifier.
	 */
	String match(WURFLRequest request, FilteredDevices filteredDevices);

    String normalize(String userAgent);
}
