/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.request.UserAgentNormalizerChain;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.request.normalizer.generic.*;
import net.sourceforge.wurfl.core.request.normalizer.specific.*;

/**
 * Factory class for matchers chain.
 * <p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: MatcherChainFactory.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class MatcherChainFactory {

	private final MatcherChain chain = new MatcherChain();


    private static UserAgentNormalizerChain createGenericNormalizers() {
        return new UserAgentNormalizerChain(
                new UserAgentNormalizer[]{
                        new SerialNumberNormalizer(),
                        new BlackBerryNormalizer(),
                        new UPLinkNormalizer(),
                        new YesWAPNormalizer(),
                        new BabelFishNormalizer(),
                        new LocaleRemover()
                }
        );
    }


    public MatcherChainFactory() {
        init();
    }

    private void init() {
        UserAgentNormalizerChain genericNormalizers = createGenericNormalizers();

		chain.add(new NokiaMatcher(genericNormalizers));

        chain.add(new LGUPLUSMatcher(genericNormalizers));
        UserAgentNormalizer androidNormalizer = genericNormalizers.add(new AndroidNormalizer());
        chain.add(new AndroidMatcher(androidNormalizer));
        
		chain.add(new SonyEricssonMatcher(genericNormalizers));
		chain.add(new MotorolaMatcher(genericNormalizers));


		chain.add(new BlackBerryMatcher(genericNormalizers));

		chain.add(new SiemensMatcher(genericNormalizers));

		chain.add(new SagemMatcher(genericNormalizers));


		chain.add(new SamsungMatcher(genericNormalizers));

		chain.add( new PanasonicMatcher(genericNormalizers));

		chain.add(new NecMatcher(genericNormalizers));
		chain
				.add(new QtekMatcher(genericNormalizers));

		chain.add(new MitsubishiMatcher(genericNormalizers));

		chain.add(new PhilipsMatcher(genericNormalizers));
                UserAgentNormalizer lgNormalizer = genericNormalizers.add(new LGNormalizer());

		chain.add(new LGMatcher(lgNormalizer));

		chain.add(new AppleMatcher(genericNormalizers));


		chain.add( new KyoceraMatcher(genericNormalizers));
		chain.add(new AlcatelMatcher(genericNormalizers))
        ;
		chain.add(new SharpMatcher(genericNormalizers));
		chain.add(new SanyoMatcher(genericNormalizers));
		chain
				.add( new BenQMatcher(genericNormalizers));
		chain.add(new PantechMatcher(genericNormalizers));

		chain.add(new ToshibaMatcher(genericNormalizers));
		chain.add(new GrundigMatcher(genericNormalizers));
		chain.add(new HTCMatcher(genericNormalizers));

        chain.add(new BotMatcher(genericNormalizers));
        
		chain.add(new SPVMatcher(genericNormalizers));
		chain.add(new WindowsCEMatcher(genericNormalizers));
		chain.add(new PortalmmmMatcher(genericNormalizers))
        ;
		chain.add( new DoCoMoMatcher(genericNormalizers));
		chain.add( new KDDIMatcher(genericNormalizers));

        chain.add(new VodafoneMatcher(genericNormalizers));
        
        chain.add(new MaemoBrowserMatcher(genericNormalizers.add(new MaemoBrowserNormalizer())));

		chain.add(new OperaMiniMatcher(genericNormalizers));
		
		chain.add(new ChromeMatcher(genericNormalizers.add(new ChromeNormalizer())));


		chain.add(new AOLMatcher(genericNormalizers));
		chain.add(new OperaMatcher(genericNormalizers));
		chain.add(new KonquerorMatcher(genericNormalizers.add(new KonquerorNormalizer())));
		chain.add(new FirefoxMatcher(genericNormalizers.add(new FirefoxNormalizer())));
		chain.add(new SafariMatcher(genericNormalizers.add(new SafariNormalizer())));
		chain.add(new MSIEMatcher(genericNormalizers.add(new MSIENormalizer())));
		
		chain.add(new CatchAllMatcher(genericNormalizers));
	}

	public MatcherChain create() {
		return chain;
	}
}
