/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: MotorolaMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class MotorolaMatcher extends AbstractMatcher {

    private static final int MOTOROLA_TOLLERANCE = 5;

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public MotorolaMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
     * Intercept all UAs starting with "Mot-", or containing "MOT-" or
     * "Motorola".
     */
    public boolean canHandle(String userAgent) {
        return (userAgent.startsWith("Mot-")
                || org.apache.commons.lang.StringUtils.contains(userAgent, "MOT-") || org.apache.commons.lang.StringUtils
                .contains(userAgent, "Motorola"));
    }

    /**
     * If UA don't starts with "Mot-","MOT-" or "Motorola" then apply LD(5)
     * otherwise apply default.
     */
    protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
                                              String userAgent) {
        if (userAgent.startsWith("Mot-") || userAgent.startsWith("MOT-")
                || userAgent.startsWith("Motorola")) {
            return super.lookForMatchingUserAgent(userAgentsSet, userAgent);
        }

        return StringUtils.ldMatch(userAgentsSet, userAgent,
                MOTOROLA_TOLLERANCE);
    }

    /**
     * if UA contains "MIB/2.2" or "MIB/BER2.2", return "mot_mib22_generic"
     * otherwise return "generic".
     */
    protected String applyRecoveryMatch(WURFLRequest request,
                                                FilteredDevices filteredDevices) {
        String userAgent = request.getUserAgent();
        if ((userAgent.indexOf("MIB/2.2") != -1)
                || (userAgent.indexOf("MIB/BER2.2") != -1)) {
            return "mot_mib22_generic";
        }

        return Constants.GENERIC;
    }

}
