/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: NecMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class NecMatcher extends AbstractMatcher {
	
	private static final int NEC_LD_TOLLERANCE = 2;

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public NecMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
	 * Checks UA starts with "NEC-" or "KGT"
	 */
	public boolean canHandle(String userAgent) {
		return (userAgent.startsWith("NEC") || userAgent.startsWith("KGT"));
	}

	/**
	 * If UA starts with "NEC", apply default, else apply LD(2).
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

		if (userAgent.startsWith("NEC")) {
			return super.lookForMatchingUserAgent(userAgentsSet, userAgent);
		}

		if (logger.isDebugEnabled()) {
			logger.debug("Applying LD(" + NEC_LD_TOLLERANCE + " UA: " + userAgent);
		}
		
		return StringUtils.ldMatch(userAgentsSet, userAgent, NEC_LD_TOLLERANCE);

	}

}
