/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import org.apache.commons.lang.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: NokiaMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class NokiaMatcher extends AbstractMatcher {


    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public NokiaMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
	 * Checks UA contains "Nokia".
	 */
	public boolean canHandle(String userAgent) {
		return StringUtils.contains(userAgent, "Nokia");
	}

    /**
     */
    protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

        int tolerance = net.sourceforge.wurfl.core.utils.StringUtils.indexOfAnyOrLength(userAgent, new String[]{"/", " "}, userAgent.indexOf("Nokia"));
        if (logger.isDebugEnabled()) {
            logger.debug("Applying RIS with tolerance [" + tolerance + "] UA: " + userAgent);
        }
        return net.sourceforge.wurfl.core.utils.StringUtils.risMatch(userAgentsSet, userAgent, tolerance);
    }

    /**
     * Search for "Series60" and "Series80". Return "nokia_generic_series60" and
     * "nokia_generic_series80" respectively in case of success
     */
    protected String applyRecoveryMatch(WURFLRequest request,
                                        FilteredDevices filteredDevices) {
        
        String userAgent = request.getUserAgent();

        if (logger.isDebugEnabled()) {
            logger.debug("Applying Nokia Recovery Match on User-Agent: "
                    + userAgent);
        }

        if (StringUtils.contains(userAgent, "Series60")) {
            return "nokia_generic_series60";
        }
        if (StringUtils.contains(userAgent, "Series80")) {
            return "nokia_generic_series80";
        }
        return Constants.GENERIC;

	}

}
