/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;
import net.sourceforge.wurfl.core.utils.UserAgentUtils;

import java.util.HashMap;
import java.util.Map;
import java.util.SortedSet;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: OperaMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class OperaMatcher extends AbstractMatcher {

    private static final int OPERA_TOLERANCE = 1;

    private static final String OPERA = "Opera";

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public OperaMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }


    /**
        * Checks given UA contains "Opera".
        */
       public boolean canHandle(String userAgent) {
           return !UserAgentUtils.isMobileBrowser(userAgent) && org.apache.commons.lang.StringUtils.contains(userAgent, OPERA);
       }

    /**
     *
     */
    protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {
        return StringUtils.ldMatch(userAgentsSet, userAgent, OPERA_TOLERANCE);
    }

    private static final Map OPERAS = new HashMap();
    static {
        OPERAS.put("", "opera");
        OPERAS.put("7", "opera_7");
        OPERAS.put("8", "opera_8");
        OPERAS.put("9", "opera_9");
        OPERAS.put("10", "opera_10");
    }

    protected String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {
        String operaVersion = operaVersion(request.getUserAgent());
        String id = (String) OPERAS.get(operaVersion);
        if (id == null) {
            id = "opera";
        }
        return filteredDevices.containsDevice(id) ? id : Constants.GENERIC;
    }

    public static final Pattern OPERA_VERSION_PATTERN = Pattern.compile(".*Opera[\\s/](\\d+).*");

    private String operaVersion(String userAgent) {
        final Matcher matcher = OPERA_VERSION_PATTERN.matcher(userAgent);
        return matcher.matches() ? matcher.group(1) : "";
    }
}
