/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.UserAgentUtils;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: OperaMiniMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class OperaMiniMatcher extends AbstractMatcher {


    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public OperaMiniMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    public boolean canHandle(String userAgent) {
		return StringUtils.contains(userAgent, "Opera Mini");
	}

    private static final Map OPERA_MINI = new HashMap();
    static {
        OPERA_MINI.put("Opera Mini/1", "browser_opera_mini_release1");
        OPERA_MINI.put("Opera Mini/2", "browser_opera_mini_release2");
        OPERA_MINI.put("Opera Mini/3", "browser_opera_mini_release3");
        OPERA_MINI.put("Opera Mini/4", "browser_opera_mini_release4");
        OPERA_MINI.put("Opera Mini/5", "browser_opera_mini_release5");     
    }

    protected String applyRecoveryMatch(WURFLRequest request,
                                        FilteredDevices filteredDevices) {
        String match = null;

        String key = (String) CollectionUtils.find(OPERA_MINI.keySet(), UserAgentUtils.isContainedIn(request.getUserAgent()));
        if (key != null) {
            match = (String) OPERA_MINI.get(key);
        }
        return match;

    }

}
