/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: PantechMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class PantechMatcher extends AbstractMatcher {
	
	private static final int PANTECH_LD_TOLLERANCE = 4;

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public PantechMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }


    /**
	 * Checks given UA starts with "Pantech","PANTECH","PT-" or "PG-"
	 */
	public boolean canHandle(String userAgent) {
		return (userAgent.startsWith("Pantech") || userAgent.startsWith("PT-") || userAgent.startsWith("PANTECH") || userAgent
				.startsWith("PG-"));
	}

	/**
	 * If starts with "Pantech" applies LD(4) otherwise default.
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

		if (userAgent.startsWith("Pantech")) {
			
			if (logger.isDebugEnabled()) {
				logger.debug("Applying LD(" + PANTECH_LD_TOLLERANCE + ") UA: " + userAgent);
			}
			
			return StringUtils.ldMatch(userAgentsSet, userAgent, PANTECH_LD_TOLLERANCE);
		}
		else {

			return super.lookForMatchingUserAgent(userAgentsSet, userAgent);
		}
	}

}
