/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.strategy.RISMatcher;
import net.sourceforge.wurfl.core.strategy.StringMatcher;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;
import org.apache.commons.lang.text.StrBuilder;

import java.util.SortedSet;

/**
 * This UserAgentHandler handles the SPV devices.
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: SPVMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class SPVMatcher extends AbstractMatcher {

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public SPVMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
	 * Check given UA contains "SPV"
	 */
	public boolean canHandle(String userAgent) {
		return org.apache.commons.lang.StringUtils.contains(userAgent, "SPV");
	}

	/**
	 * <p>
	 * Apply RIS after first ; on SPV  
	 * </p>
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
			String userAgent) {

		
		// Default values
		StringMatcher matcher = RISMatcher.INSTANCE;
		int tollerance = StringUtils.indexOfOrLength(userAgent, ";", StringUtils.indexOfOrLength(userAgent, "SPV"));
		
		if(logger.isDebugEnabled()){
			
			StrBuilder logBuilder = new StrBuilder();
			logBuilder.append("Applying ");
			
			logBuilder.append(matcher);
			logBuilder.append(tollerance).append(") UA: ");
			logBuilder.append(userAgent);
		}

		return matcher.match(userAgentsSet, userAgent, tollerance);
	}

}
