/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.UserAgentUtils;
import org.apache.commons.lang.StringUtils;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: SafariMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class SafariMatcher extends AbstractMatcher {

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public SafariMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
	 * Checks given UA contain "Safari"
	 */
	public boolean canHandle(String userAgent) {
		return !UserAgentUtils.isMobileBrowser(userAgent) && userAgent.startsWith("Mozilla") && StringUtils.contains(userAgent, "Safari");
	}


	protected String applyRecoveryMatch(WURFLRequest request,
			FilteredDevices filteredDevices) {
		
		String userAgent = request.getUserAgent();
		
		if(StringUtils.contains(userAgent, "Macintosh") || StringUtils.contains(userAgent, "Windows")){
			return Constants.GENERIC_WEB_BROWSER;
		}
		else {
			return Constants.GENERIC;
		}
		
	}

}
