/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: SamsungMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class SamsungMatcher extends AbstractMatcher {


    private static final String[] SAMSUNG_PREFIXES = new String[]{"SEC-", "SAMSUNG", "SPH", "SGH", "SCH"};
    private static final String[] SAMSUNG_INFIXES = new String[]{"Samsung/SGH", "Samsung"};

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public SamsungMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    public boolean canHandle(String userAgent) {
        return (StringUtils.containsAnyOf(userAgent, SAMSUNG_INFIXES)
                || StringUtils.startsWithAnyOf(userAgent, SAMSUNG_PREFIXES));
    }
    /**
     * <p>
     * If UA starts with one of the following ("SEC-", "SAMSUNG-", "SCH"), apply
     * default.
     * </p>
     * <p>
     * Else if UA starts with one of the following ("Samsung-","SPH", "SGH" ), apply RIS(FP).
     * </p>
     * <p>
     * Else if UA starts with "SAMSUNG/", apply RIS(SS).
     * </p>
     */
    protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

        int tolerance = tolerance(userAgent);
        if (logger.isDebugEnabled()) {
            logger.debug("Applying RIS with Tolerance[" + tolerance + "] on UA: " + userAgent);
        }
        return StringUtils.risMatch(userAgentsSet, userAgent, tolerance);

    }

    private static final String[] SAMSUNGS = new String[]{"SEC-", "SAMSUNG-", "SCH", "Samsung", "SPH", "SGH", "SAMSUNG/"};
    private static final String[] THRESHOLD_CHARACTERS = new String[] {" ", "/"};
    private int tolerance(String userAgent) {
        for(int i = 0; i < SAMSUNGS.length; i++) {
            int index = userAgent.indexOf(SAMSUNGS[i]);
            if(index != -1) {
                return StringUtils.indexOfAnyOrLength(userAgent, THRESHOLD_CHARACTERS, index);
            }
        }
        return userAgent.length();
    }

}
