/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: SonyEricssonMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class SonyEricssonMatcher extends AbstractMatcher {


    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public SonyEricssonMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
	 * Checks given UA contains "SonyEricsson"
	 */
	public boolean canHandle(String userAgent) {
		return org.apache.commons.lang.StringUtils.contains(userAgent, "SonyEricsson");
	}

	/**
	 * If UA starts with "SonyEricsson", apply RIS with FS as a threshold. If UA
	 * contains "SonyEricsson" somewhere in the middle, apply RIS with threshold
	 * second slash
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {
		if (userAgent.startsWith("SonyEricsson")) {
			return super.lookForMatchingUserAgent(userAgentsSet, userAgent);
		}

		int tollerance = StringUtils.secondSlash(userAgent);

		if (logger.isDebugEnabled()) {
			logger.debug("Appling RIS(SS) UA: " + userAgent);
		}

		return StringUtils.risMatch(userAgentsSet, userAgent, tollerance);

	}

}
