/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;
import org.apache.commons.lang.text.StrBuilder;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: VodafoneMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class VodafoneMatcher extends AbstractMatcher {

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public VodafoneMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    /**
     * Checks given UA starts with "Vodafone"
     */
    public boolean canHandle(String userAgent) {
        return userAgent.startsWith("Vodafone");
    }

    protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

        int tolerance = StringUtils.ordinalIndexOfOrLength(userAgent, "/", 3);
        log(userAgent, tolerance);

        return StringUtils.risMatch(userAgentsSet, userAgent, tolerance);

    }

    private void log(String userAgent, int tolerance) {
        if (logger.isDebugEnabled()) {

            StrBuilder logBuilder = new StrBuilder();
            logBuilder.append("Applying RIS: ");
            logBuilder.append(tolerance).append(") UA: ");
            logBuilder.append(userAgent);
            logger.debug(logBuilder.toString());
        }
    }


}
