/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.matchers;

import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: WindowsCEMatcher.java 672 2011-06-22 19:22:21Z ermanno.franco $
 */
public class WindowsCEMatcher extends AbstractMatcher {
	
	private static final int WINDOWS_CE_TOLLERANCE = 3;

    /**
     * Build AbstractMatcher by handler and collected devices by user-agent.
     *
     * @param normalizer
     */
    public WindowsCEMatcher(UserAgentNormalizer normalizer) {
        super(normalizer);
    }


    public boolean canHandle(String userAgent) {
		return org.apache.commons.lang.StringUtils.contains(userAgent, "Mozilla/")
                && net.sourceforge.wurfl.core.utils.StringUtils.containsAnyOf(userAgent,
                new String[]{"Windows CE", "WindowsCE", "ZuneWP7"});
	}

	/**
	 * Apply LD(3).
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

		if (logger.isDebugEnabled()) {
			logger.debug("Applying LD(" + WINDOWS_CE_TOLLERANCE + ") UA: " + userAgent);
		}

		return StringUtils.ldMatch(userAgentsSet, userAgent, WINDOWS_CE_TOLLERANCE);
	}

	/**
	 * return "generic_ms_mobile_browser_ver1"
	 */
	public String applyRecoveryMatch(WURFLRequest request) {
		return "generic_ms_mobile_browser_ver1";
	}

}
