/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.request;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.request.normalizer.generic.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * UserAgentNormalizerFactory default implementation.
 * <p/>
 * <p>
 * Build a UserAgentNormalizerChain with the WURFL UserAgentNormalizers.
 * </p>
 *
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: DefaultUserAgentNormalizerFactory.java 649 2011-05-20 18:28:18Z ermanno.franco $
 */
public class DefaultUserAgentNormalizerFactory implements UserAgentNormalizerFactory {

    /**
     * Log
     */
    private final Logger logger = LoggerFactory.getLogger(DefaultUserAgentNormalizerFactory.class);

    /**
     * {@inheritDoc}
     *
     * @return UserAgentNormalizerChain
     */
    public UserAgentNormalizer create() {

        logger.debug("Creating UserAgentNormalizerChain...");

        UserAgentNormalizerChain chain = new UserAgentNormalizerChain();
        chain.add(new SerialNumberNormalizer());
        chain.add(new BlackBerryNormalizer());
        chain.add(new UPLinkNormalizer());
        chain.add(new YesWAPNormalizer());
        chain.add(new BabelFishNormalizer());

        return chain;
    }

}
