/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.request;

import net.sourceforge.wurfl.core.utils.UserAgentUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.Validate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.http.HttpServletRequest;

/**
 * @author Fantayeneh Asres Gizaw
 */
public class FastWURFLRequestFactory implements WURFLRequestFactory {

    /**
     * Logger
     */
    private final Logger logger = LoggerFactory.getLogger(FastWURFLRequestFactory.class);

    /**
     * User-Agent resolver
     */
    private final UserAgentResolver userAgentResolver;


    public FastWURFLRequestFactory() {
        this(new DefaultUserAgentResolver());
    }

    public FastWURFLRequestFactory(UserAgentResolver userAgentResolver) {
        this.userAgentResolver = userAgentResolver;
    }

    /**
     * Create a instance of {@link DefaultWURFLRequest} from an instance of
     * {@link HttpServletRequest}.
     * <p/>
     * <p>
     * Uses UserAgentResolver to resolve request user-agent and
     * </p>
     *
     * @param sourceRequest The HttpServletRequest from which build the WURFLRequest.
     */
    public WURFLRequest createRequest(HttpServletRequest sourceRequest) {

        Validate.notNull(sourceRequest, "The sourceRequest must be not null");

        String userAgent = StringUtils.trimToEmpty(userAgentResolver
                .resolve(sourceRequest));

        String uaProf = UserAgentUtils.getUaProfile(sourceRequest);

        DefaultWURFLRequest request = new DefaultWURFLRequest(userAgent, uaProf);

        if (logger.isDebugEnabled()) {
            logger.debug("Created DefaultWURFLRequest: " + request);
        }

        return request;
    }

    /**
     * Create a instance of {@link DefaultWURFLRequest} from an instance of
     * {@link HttpServletRequest}.
     * <p/>
     *
     * @param userAgent The User-Agent from which build the WURFLRequest.
     */
    public WURFLRequest createRequest(final String userAgent) {

        String ua = StringUtils.trimToEmpty(userAgent);
        return new DefaultWURFLRequest(ua, null);
    }
}
