/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.request;

import javax.servlet.http.HttpServletRequest;

/**
 * General interface of WURFLRequest Factory
 * <p>
 * To extends WURFLRequest is necessary also extending this interface to build
 * custom {@link WURFLRequest} implementation
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: WURFLRequestFactory.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public interface WURFLRequestFactory {

	/**
	 * Build a {@link WURFLRequest} instance from given request. The
	 * <code>sourceRequest</code> class may change by deploy environment.
	 * 
	 * @param sourceRequest
	 *            A request object from which build custom {@link WURFLRequest}.
	 * @return A instance of {@link WURFLRequest} builded from
	 *         <code>sourceRequest</code>.
	 */
	WURFLRequest createRequest(HttpServletRequest sourceRequest);

	/**
	 * Build WURFLRequest using given User-Agent.
	 * 
	 * @param userAgent
	 *            The user-agent used to build WURFLRequest.
	 * @return Built WURFLRequest.
	 */
	WURFLRequest createRequest(String userAgent);

}
