/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.request.normalizer.generic;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Yahoo Babelfish normalizer.
 * 
 * <p>
 * Strips out the "via babelfish.yahoo.com" from the user-agent.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: BabelFishNormalizer.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class BabelFishNormalizer implements UserAgentNormalizer {

	private static final Pattern BABEL_FISH_PATTERN = Pattern
			.compile("\\s*\\(via babelfish.yahoo.com\\)\\s*");

    /**
	 * Replace the "via babelfish.yahoo.com" with "".
	 */
	public String normalize(String userAgent) {

		Matcher matcher = BABEL_FISH_PATTERN.matcher(userAgent);
		return matcher.replaceAll("");

	}

}
