/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.request.normalizer.generic;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * YesWAP UserAgentNormalizer.
 * 
 * <p>
 * Remove the YesWAP from user-agent.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: YesWAPNormalizer.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class YesWAPNormalizer implements UserAgentNormalizer {

	/** YesWAP regex pattern */
	private static final Pattern YES_WAP_PATTERN = Pattern
			.compile("\\s*Mozilla/4\\.0 \\(YesWAP mobile phone proxy\\)");

    /**
	 * Replace the "YesWAP mobile phone proxy" with "".
	 */
	public String normalize(String userAgent) {

		String normalizedUserAgent = userAgent;

		Matcher matcher = YES_WAP_PATTERN.matcher(userAgent);
		if (matcher.find()) {
			normalizedUserAgent = matcher.replaceAll("");
		}

		return normalizedUserAgent;
	}

}
