/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.request.normalizer.specific;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * This Normalizer returns Konqueror user agent with the major version.
 * 
 * e.g Mozilla/5.0 (compatible; Konqueror/4.1; Linux) KHTML/4.1.2 (like Gecko)
 * -> Konqueror/4
 * 
 * @author Tommaso Teofili
 * @author Filippo De Luca
 * 
 * @version $Id: KonquerorNormalizer.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class KonquerorNormalizer implements UserAgentNormalizer {

    public static final Pattern KONQUEROR_PATTERN = Pattern.compile("(Konqueror\\/\\d)");
	/**
	 * Return the Konqueror user agent with the major version
	 * 
	 * e.g Mozilla/5.0 (compatible; Konqueror/4.1; Linux) KHTML/4.1.2 (like
	 * Gecko) -> Konqueror/4
	 * 
	 * @param userAgent
	 * @return String
	 */
	public String normalize(String userAgent) {
        Matcher matcher = KONQUEROR_PATTERN.matcher(userAgent);
        return matcher.find() ? matcher.group(1) : userAgent;

	}

}
