/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.request.normalizer.specific;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import org.apache.commons.lang.text.StrBuilder;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @author Tommaso Teofili
 * 
 * @version $Id: SafariNormalizer.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class SafariNormalizer implements UserAgentNormalizer {
	
	private static final Pattern PATTERN = Pattern.compile("(Mozilla\\/5\\.0.*)(\\;\\s*U\\;.*?)(Safari\\/\\d{0,3})");
	

	/**
	 * Return the safari user agent stripping out 
	 * 	- all the chararcters between U; and Safari/xxx
	 *	
	 *  e.g Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_4_11; fr) AppleWebKit/525.18 (KHTML, like Gecko) Version/3.1.1 Safari/525.18
	 * 		becomes
	 * 		Mozilla/5.0 (Macintosh Safari/525
	 * 
	 */
	public String normalize(String userAgent) {
		
		String normalized = userAgent;
		
		Matcher matcher = PATTERN.matcher(userAgent);
		
		if(matcher.find() && matcher.groupCount() >= 3) {
			StrBuilder normalizedBuilder = new StrBuilder();
			normalizedBuilder.append(matcher.group(1).trim()).append(" ").append(matcher.group(3).trim());
			
			normalized = normalizedBuilder.toString();
		}
		
		return normalized;
	}

}
