/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

import org.apache.commons.lang.text.StrBuilder;

/**
 * Capability generic consistency exception
 * 
 * <p>
 * This is a abstract class representing all {@link DeviceConsistencyException}
 * regarding single capability.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: CapabilityConsistencyException.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public abstract class CapabilityConsistencyException extends
		DeviceConsistencyException {

	/** Serial */
	private static final long serialVersionUID = 10L;

	/** The capability target of this Exception */
	private String capability;

	/**
	 * Build the Exception by devices and capability.
	 * 
	 * @param device
	 */
	public CapabilityConsistencyException(ModelDevice device, String capability) {
		super(device, new StrBuilder("Device: ").append(device.getID()).append(" Capability: ").append(capability).append(
		" consistency error").toString());
		
		this.capability = capability;
	}
	
	/**
	 * Build the Exception by devices and capability.
	 * 
	 * @param device
	 */
	public CapabilityConsistencyException(ModelDevice device, String capability, String message) {
		super(device, message);
		this.capability = capability;
	}

	/**
	 * Return the capability object of this Exception.
	 * 
	 * @return The identifier of the target capability.
	 */
	public String getCapability() {
		return capability;
	}

}
