/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

import net.sourceforge.wurfl.core.utils.StringUtils;
import org.apache.commons.lang.text.StrBuilder;

import java.util.List;

/**
 * Circular hierarchy exception.
 * 
 * <p>
 * This Exception is thrown when is detected a ModelDevice member of a circular
 * hierarchy. A circular hierarchy don not have a start and a end device,
 * iterating over it take in a infinite loop.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: CircularHierarchyException.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class CircularHierarchyException extends HierarchyConsistencyException {

	/** serial */
	private static final long serialVersionUID = 10L;

	/**
	 * Build this Exception by a hierarchy.
	 * 
	 * @param hierarchy
	 *            The list of {@link ModelDevice}s member of this circular
	 *            hierarchy.
	 */
	public CircularHierarchyException(List hierarchy) {
		super(hierarchy, new StrBuilder("Circular hierarchy detected: [ ")
				.append(StringUtils.hierarchyAsString(hierarchy)).append("]")
				.toString());

	}

}
