/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

import net.sourceforge.wurfl.core.WURFLRuntimeException;
import org.apache.commons.lang.text.StrBuilder;

/**
 * The device is not managed by model.
 * 
 * <p>
 * This exception is thrown if the referenced device is not managed by model.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: DeviceNotInModelException.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class DeviceNotInModelException extends WURFLRuntimeException {

	/** serial */
	private static final long serialVersionUID = 10L;

	/** The unmanaged ModelDevice */
	private ModelDevice modelDevice;

	/**
	 * Build DeviceNotInModelException by source ModelDevice.
	 * 
	 * @param modelDevice
	 *            The exception source.
	 */
	public DeviceNotInModelException(ModelDevice modelDevice) {
		super(new StrBuilder("Device: ").append(modelDevice.getID()).append(
				" is not managed by model").toString());

		this.modelDevice = modelDevice;
	}

	/**
	 * Returns the held ModelDevice source of this exception.
	 * 
	 * @return Not defined ModelDevice.
	 */
	public ModelDevice getModelDevice() {
		return modelDevice;
	}

}
