/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

import org.apache.commons.lang.text.StrBuilder;

/**
 * Generic group consistency exception.
 * 
 * <p>
 * This abstract Exception is thrown when a {@link ModelDevice} has a bad group
 * definition.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: GroupConsistencyException.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public abstract class GroupConsistencyException extends
		DeviceConsistencyException {

	/** Serial */
	private static final long serialVersionUID = 10L;

	/** The group object of this Exception. */
	private String group;

	/**
	 * Build this Exception by Group identifier and source device.
	 * 
	 * @param device
	 *            The ModelDevice having bad group definition.
	 * @param group
	 *            The group object of this Exception.
	 */
	public GroupConsistencyException(ModelDevice device, String group) {

		super(device, new StrBuilder("Group: ").append(group).append(
				" in device: ").append(device.getID()).append(
				" consistency exception").toString());

		this.group = group;
	}

	/**
	 * Build this Exception by Group identifier, source device and message.
	 * 
	 * @param device
	 *            The ModelDevice having bad group definition.
	 * @param group
	 *            The group object of this Exception.
	 * @param message
	 *            The message displaying by this exception.
	 */
	public GroupConsistencyException(ModelDevice device, String group,
			String message) {
		super(device, message);

		this.group = group;

	}

	/**
	 * Return the group object of this exception.
	 * 
	 * @return Identifier of group object of this instance.
	 */
	public String getGroup() {
		return group;
	}

}
