/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

import org.apache.commons.lang.text.StrBuilder;

/**
 * Unknow capability exception.
 * 
 * <p>
 * This Exception is thrown when a {@link ModelDevice} define a capability not
 * defined by <code>generic</code> device.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: InexistentCapabilityException.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class InexistentCapabilityException extends
		CapabilityConsistencyException {

	/** serial */
	private static final long serialVersionUID = 10L;

	/**
	 * Build this Exception from a {@link ModelDevice} and the not defined
	 * capability.
	 * 
	 * @param device
	 *            A {@link ModelDevice} instance defining capability.
	 * @param capability
	 *            The capability is not defined by <code>generic</code>
	 */
	public InexistentCapabilityException(ModelDevice device, String capability) {
		super(device, capability, new StrBuilder("Device: ").append(
				device.getID()).append(" define unknow capability: ").append(
				capability).toString());
	}

}
