/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

import net.sourceforge.wurfl.core.utils.StringUtils;
import org.apache.commons.lang.text.StrBuilder;

import java.util.List;

/**
 * Orphan hierarchy exception
 * 
 * <p>
 * This Exception is thrown when a Hierarchy with null root is found.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: OrphanHierarchyException.java 633 2011-05-11 20:37:08Z ermanno.franco $
 */
public class OrphanHierarchyException extends HierarchyConsistencyException {

	/** serial */
	private static final long serialVersionUID = 10L;

	/**
	 * Build exception by orphan hierarchy.
	 * 
	 * @param hierarchy
	 *            Detected orphan hierarchy.
	 */
	public OrphanHierarchyException(List hierarchy) {
		super(hierarchy, new StrBuilder("Orphan exception in hierarchy: [").append(
				StringUtils.hierarchyAsString(hierarchy)).append("]")
				.toString());
	}

}
