/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

/**
 * This is a mutable {@link WURFLModel} interface. All classes need to modify
 * the model must referencing this interface.
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: WURFLAccessibleModel.java 652 2011-05-29 20:29:52Z ermanno.franco $
 */
public interface WURFLAccessibleModel extends WURFLModel {

	/**
	 * Applies a patch to model runtime.
	 * 
	 * @param patch
	 *            The resource represents patch.
	 */
	void applyPatch(WURFLResource patch);

	/**
	 * Applies several patches to model runtime.
	 * 
	 * @param patches
	 *            The resources represent patches.
	 */
	void applyPatches(WURFLResources patches);

	// Event handling *****************************************************

	/**
	 * Add a {@link WURFLModelListener} observe this model.
	 * 
	 * @param listener
	 *    The listener to add.
	 */
	void addModelListener(WURFLModelListener listener);

	/**
	 * Remove a {@link WURFLModelListener} observing this model. If the listener
	 * are not observing this model then the operation is ignored.
	 * 
	 * @param listener
	 *    The listener to remove.
	 */
	void removeModelListener(WURFLModelListener listener);
}
