/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.utils;

import java.util.Map;

/**
 * @author Fantayeneh Asres Gizaw
 */
public abstract class CollectionFactory {

    private static final ConcurrentCollectionFactory CURRENT_CONCURRENT_COLLECTION_FACTORY;

    static {
        boolean AT_LEAST_JAVA_15 = System.getProperty("java.version").indexOf("1.4") != 0;
        if (AT_LEAST_JAVA_15) {
            CURRENT_CONCURRENT_COLLECTION_FACTORY = new JDK5ConcurrentCollectionFactory();
        } else {
            CURRENT_CONCURRENT_COLLECTION_FACTORY = new BackportConcurrentCollectionFactory();
        }
    }

    public static Map createConcurrentHashMap() {
        return createConcurrentHashMap(
                ConcurrentCollectionFactory.DEFAULT_INITIAL_CAPACITY,
                ConcurrentCollectionFactory.DEFAULT_LOAD_FACTOR,
                ConcurrentCollectionFactory.DEFAULT_CONCURRENT_WRITES);
    }

    public static Map createConcurrentHashMap(int initialCapacity, float loadFactor, int concurrentWrites) {
        return CURRENT_CONCURRENT_COLLECTION_FACTORY.createConcurrentHashMap(initialCapacity, loadFactor, concurrentWrites);
    }


    interface ConcurrentCollectionFactory {
        int DEFAULT_INITIAL_CAPACITY = 6000;
        float DEFAULT_LOAD_FACTOR = 0.75f;
        int DEFAULT_CONCURRENT_WRITES = 16;

        Map createConcurrentHashMap(int initialCapacity, float loadFactor, int concurrentWrites);

    }

    private static class JDK5ConcurrentCollectionFactory implements ConcurrentCollectionFactory {
        public Map createConcurrentHashMap(int initialCapacity, float loadFactor, int concurrentWrites) {
            return new java.util.concurrent.ConcurrentHashMap(initialCapacity);
        }

    }

    private static class BackportConcurrentCollectionFactory implements ConcurrentCollectionFactory {

        public Map createConcurrentHashMap(int initialCapacity, float loadFactor, int concurrentWrites) {
            return new edu.emory.mathcs.backport.java.util.concurrent.ConcurrentHashMap(initialCapacity);
        }

    }


}
