/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.utils;

import org.apache.commons.collections.Predicate;

/**
 * @author Fantayeneh Asres Gizaw
 */
public final class Predicates {
    private Predicates() {
    }

    public static Predicate isContainedIn(final String string) {
        return new IsContainedIn(string);
    }

    public static Predicate startsWith(String s) {
        return new StartsWith(s);
    }


    private static final class IsContainedIn implements Predicate {

        private final String userAgent;

        private IsContainedIn(String userAgent) {
            this.userAgent = userAgent;
        }

        public boolean evaluate(Object object) {
            return org.apache.commons.lang.StringUtils.contains(userAgent, (String) object);
        }
    }

    private static final class StartsWith implements Predicate {
        private final String s;

        public StartsWith(String s) {
            this.s = s;
        }

        public boolean evaluate(Object object) {
            return object != null && object.toString().startsWith(s);
        }
    }


}
