/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
/* $Id: WURFLServletContextListener.java 649 2011-05-20 18:28:18Z ermanno.franco $ 
 * This file is released under the GNU General Public License. 
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2011 Luca Passani, Rome, Italy
 */
package net.sourceforge.wurfl.core.web;

import org.apache.commons.lang.StringUtils;

import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

/**
 * ServletContextListener instantiating WURFLHolder.
 * 
 * <p>
 * This class permit to instantiate WURFL at servlet context loading time:
 * 
 * <pre>
 *  &lt;web-app version=&quot;2.4&quot; xmlns=&quot;http://java.sun.com/xml/ns/j2ee&quot;
 *  xmlns:xsi=&quot;http://www.w3.org/2001/XMLSchema-instance&quot;
 *  xsi:schemaLocation=&quot;http://java.sun.com/xml/ns/j2ee http://java.sun.com/xml/ns/j2ee/web-app_2_4.xsd&quot;&gt;
 * 
 * 	&lt;context-param&gt;
 * 		&lt;param-name&gt;wurfl&lt;/param-name&gt;
 * 		&lt;param-value&gt;/WEB-INF/wurfl.zip&lt;/param-value&gt;
 * 	&lt;/context-param&gt;
 * 	
 *  &lt;context-param&gt;
 * 		&lt;param-name&gt;wurflPatch&lt;/param-name&gt;
 * 		&lt;param-value&gt;/WEB-INF/wb_patch.xml,/WEB-INF/other_patch.xml&lt;/param-value&gt;
 * 	&lt;/context-param&gt;
 * 
 * 	&lt;context-param&gt; 
 * 		&lt;param-name&gt;wurflLazy&lt;/param-name&gt;
 * 		&lt;param-value&gt;true&lt;/param-value&gt;
 * 	&lt;/context-param&gt;
 * 
 * 	&lt;!-- the ServletContext key against store the wurflHolder. This is default --&gt; 
 * 	&lt;context-param&gt; 
 * 		&lt;param-name&gt;wurflHolderKey&lt;/param-name&gt;
 * 		&lt;param-value&gt;net.sourceforge.wurfl.core.WURFLHolder&lt;/param-value&gt;
 * 	&lt;/context-param&gt;
 * 
 * 	&lt;listener&gt;
 * 		&lt;listener-class&gt;
 * 		net.sourceforge.wurfl.core.web.WURFLServletContextListener 
 * 		&lt;/listener-class&gt;
 * 	&lt;/listener&gt;
 * 
 *  &lt;/web-app&gt;
 * </pre>
 * 
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: WURFLServletContextListener.java 649 2011-05-20 18:28:18Z ermanno.franco $
 */
public class WURFLServletContextListener implements ServletContextListener, WurflWebConstants {

    /** WURFLHolder ServletContext attribute name */
    private String wurflHolderContextKey = WURFL_HOLDER_KEY;

	public void contextInitialized(ServletContextEvent servletContextEvent) {
		ServletContext servletContext = servletContextEvent.getServletContext();

		String newWurflHolderContextKey = servletContextEvent.getServletContext()
				.getInitParameter(WURFL_HOLDER_KEY_PARAM);
		if (!StringUtils.isEmpty(newWurflHolderContextKey)) {
			wurflHolderContextKey = newWurflHolderContextKey;
		}

		ServletContextWURFLHolder wurflHolder = new ServletContextWURFLHolder(servletContext);

		servletContext.setAttribute(wurflHolderContextKey, wurflHolder);

	}

	public void contextDestroyed(ServletContextEvent servletContextEvent) {

		ServletContext servletContext = servletContextEvent.getServletContext();

		servletContext.removeAttribute(wurflHolderContextKey);

	}

}
