/**
 * Copyright (c) 2011 ScientiaMobile Inc.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.spring;

import net.sourceforge.wurfl.core.DefaultWURFLHolder;
import net.sourceforge.wurfl.core.WURFLHolder;
import net.sourceforge.wurfl.core.WURFLManager;
import net.sourceforge.wurfl.core.WURFLUtils;
import org.springframework.context.ApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;

import javax.servlet.ServletContext;

/**
 * Spring context {@link WURFLHolder} decorator.
 * 
 * <p>
 * Build a new WURFLHolder from Spring ApplicationContext in ServletContext.
 * </p>
 * @deprecated Use SpringWurflManager
 *
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: SpringWebWURFLHolder.java 665 2011-06-06 21:33:57Z ermanno.franco $
 */
public class SpringWebWURFLHolder implements WURFLHolder {

	/** Delegate WURFLHolder */
	private WURFLHolder delegate;

	/**
	 * Constructor by ServletContext
	 * 
	 * @param servletContext
	 *            The ServletContext contains application context definition.
	 */
	public SpringWebWURFLHolder(ServletContext servletContext) {

		ApplicationContext appContext = WebApplicationContextUtils
				.getWebApplicationContext(servletContext);

		WURFLManager wurflManager = null;
		WURFLUtils wurflUtils = null;

		// FIXME By name or by type?
		String beansName[] = appContext.getBeanNamesForType(WURFLManager.class);
		if (beansName.length <= 0) {
			throw new IllegalStateException("A bean of type "
					+ WURFLManager.class.getName()
					+ " must be defined in application context.");

		}

		wurflManager = (WURFLManager) appContext.getBean(beansName[0]);

		// FIXME By name or by type?
		if (appContext.getBeanNamesForType(WURFLUtils.class).length > 0) {

			wurflUtils = (WURFLUtils) appContext.getBeansOfType(
					WURFLUtils.class).values().iterator().next();
		}

		this.delegate = new DefaultWURFLHolder(wurflManager, wurflUtils);
	}

	public WURFLManager getWURFLManager() {

		return delegate.getWURFLManager();
	}

	public WURFLUtils getWURFLUtils() {

		return delegate.getWURFLUtils();
	}

}
